# This runs a bash command for Titus Wormer's franc.
# More info on franc can be found here: https://github.com/wooorm/franc
#
# If franc is not installed globally on computer system, this will not work.
module Franc
  def language(str = self)
    formstr = str.gsub(/\W\s/, ' ') # Replace special chars with a space.
    `franc #{formstr}`.strip!
  rescue Errno::ENOENT
    ask_install
  end

  # Asks if user would like to install franc.
  def ask_install
    puts 'Looks like franc has not been installed yet.'
    puts 'Would you like to install it now? (y/n)'
    answer = gets.chomp!
    install(answer)
  end

  # If user presses RETURN or gives anything besides no, franc is installed.
  def install(str)
    return if %w(no n).include?(str)
    puts 'installing...'
    `npm install -g franc`
    puts "\nnpm successfully installed franc."
    true # Just for looks really, better than returning nil.
  end
end

# Add to String class.  Now usage can be:
# "example string".language
# =>"und"
class String
  include Franc
end
